@@ -5,12 +5,9 @@ use warnings;
 use Pod::Usage;
 use Config::Tiny;
 use File::Spec;
-use File::Path qw[mkpath];
 use Cwd;
 use Getopt::Long;
 use Time::Duration qw(duration_exact);
-use Module::Pluggable search_path => ['App::SmokeBox::Mini::Plugin'];
-use Module::Load;
 use POE;
 use POE::Component::SmokeBox;
 use POE::Component::SmokeBox::Smoker;
@@ -20,9 +17,9 @@ use POE::Component::SmokeBox::Recent;
 
 use vars qw($VERSION);
 
-use constant CPANURL => 'ftp://cpan.cpantesters.org/CPAN/';
+use constant CPANURL => 'ftp://ftp.funet.fi/pub/CPAN/';
 
-$VERSION = '0.21_01';
+$VERSION = '0.02';
 
 $ENV{PERL5_MINISMOKEBOX} = $VERSION;
 
@@ -48,14 +45,11 @@ sub _read_config {
   my $conf_file = File::Spec->catfile( $smokebox_dir, 'minismokebox' );
   return unless -e $conf_file;
   my $Config = Config::Tiny->read( $conf_file );
-  my @config;
   if ( defined $Config->{_} ) {
-    my $root = delete $Config->{_};
-	  @config = map { $_, $root->{$_} } grep { exists $root->{$_} }
-		              qw(debug perl indices recent backend url home);
+	return map { $_, $Config->{_}->{$_} } grep { exists $Config->{_}->{$_} }
+		qw(debug perl indices recent backend url);
   }
-  push @config, 'sections', $Config if scalar keys %{ $Config };
-  return @config;
+  return;
 }
 
 sub _get_jobs_from_file {
@@ -89,55 +83,36 @@ sub run {
   my %config = _read_config();
   my $version;
   GetOptions(
-    "help"      => sub { pod2usage(1); },
-    "version"   => sub { $version = 1 },
-    "debug"     => \$config{debug},
-    "perl=s" 	  => \$config{perl},
-    "indices"   => \$config{indices},
-    "recent"    => \$config{recent},
-    "jobs=s"    => \$config{jobs},
-    "backend=s" => \$config{backend},
-    "author=s"  => \$config{author},
-    "package=s" => \$config{package},
-    "phalanx"   => \$config{phalanx},
-    "url=s"	    => \$config{url},
-    "reverse"   => \$config{reverse},
-    "home=s"    => \$config{home},
+    "h|help"      => sub { pod2usage(1); },
+    "v|version"   => sub { $version = 1 },
+    "d|debug"     => \$config{debug},
+    "p|perl=s" 	  => \$config{perl},
+    "i|indices"   => \$config{indices},
+    "r|recent"    => \$config{recent},
+    "j|jobs=s"    => \$config{jobs},
+    "b|backend=s" => \$config{backend},
+    "a|author=s"  => \$config{author},
+    "D|package=s" => \$config{package},
+    "P|phalanx"   => \$config{phalanx},
+    "u|url=s"	  => \$config{url},
   ) or pod2usage(2);
 
   _display_version() if $version;
 
   $config{perl} = $^X unless $config{perl} and -e $config{perl};
   $ENV{PERL5_SMOKEBOX_DEBUG} = 1 if $config{debug};
-  $ENV{AUTOMATED_TESTING} = 1;   # We need this because some backends do not set it.
-  $ENV{PERL_MM_USE_DEFAULT} = 1; # And this.
-  $ENV{PERL_EXTUTILS_AUTOINSTALL} = '--defaultdeps'; # Got this from CPAN::Reporter::Smoker. Cheers, xdg!
 
   if ( $config{jobs} and -e $config{jobs} ) {
      my @jobs = _get_jobs_from_file( $config{jobs} );
      $config{jobs} = \@jobs if scalar @jobs;
   }
 
-  print "Running minismokebox with options:\n";
-  printf("%-20s %s\n", $_, $config{$_}) 
-	for grep { defined $config{$_} } qw(debug indices perl jobs backend author package phalanx reverse url home);
-
-  if ( $config{home} and ! -e $config{home} ) {
-     mkpath( $config{home} ) or die "Could not create '$config{home}': $!\n";
-  }
-
-  if ( $config{home} and ! -d $config{home} ) {
-     warn "Home option was specified but '$config{home}' is not a directory, ignoring\n";
-     delete $config{home};
-  }
-
   my $self = bless \%config, $package;
 
   $self->{sbox} = POE::Component::SmokeBox->spawn( 
 	smokers => [
 	   POE::Component::SmokeBox::Smoker->new(
 		perl => $self->{perl},
-    ( $self->{home} ? ( env => { HOME => $self->{home} } ) : () ),
 	   ),
 	],
   );
@@ -145,7 +120,7 @@ sub run {
   $self->{session_id} = POE::Session->create(
 	object_states => [
 	   $self => { recent => '_submission', dists => '_submission', },
-	   $self => [qw(_start _stop _check _child _indices _smoke _search)],
+	   $self => [qw(_start _stop _check _indices _smoke _search)],
 	],
 	heap => $self,
   )->ID();
@@ -174,19 +149,6 @@ sub _start {
 	idle => 0,
 	excess => 0,
   };
-  # Initialise plugins
-  foreach my $plugin ( $self->plugins() ) {
-     load $plugin;
-     $plugin->init( $self->{sections} );
-  }
-  return;
-}
-
-sub _child {
-  my ($kernel,$self,$reason,$child) = @_[KERNEL,OBJECT,ARG0,ARG1];
-  return unless $reason eq 'create';
-  push @{ $self->{_sessions} }, $child->ID();
-  $kernel->detach_child( $child );
   return;
 }
 
@@ -206,7 +168,6 @@ sub _stop {
   print "minismokebox avg run: \t", $stats[3], "\n";
   print "minismokebox min run: \t", $stats[4], "\n";
   print "minismokebox max run: \t", $stats[5], "\n";
-  $kernel->call( $_, 'sbox_stop', @stats ) for @{ $self->{_sessions} };
   return;
 }
 
@@ -300,9 +261,6 @@ sub _submission {
      warn $data->{error}, "\n";
      return;
   }
-  if ( $state eq 'recent' and $self->{reverse} ) {
-     @{ $data->{$state} } = reverse @{ $data->{$state} };
-  }
   foreach my $distro ( @{ $data->{$state} } ) {
      print "Submitting: $distro\n";
      $kernel->post( $self->{sbox}->session_id(), 'submit', event => '_smoke', job => 
@@ -321,7 +279,6 @@ sub _smoke {
   my $dist = $data->{job}->module();
   my ($result) = $data->{result}->results;
   print "Distribution: '$dist' finished with status '$result->{status}'\n";
-  $kernel->post( $_, 'sbox_smoke', $data ) for @{ $self->{_sessions} };
   my $run_time = $result->{end_time} - $result->{start_time};
   $self->{stats}->{max_run} = $run_time if $run_time > $self->{stats}->{max_run};
   $self->{stats}->{min_run} = $run_time if $self->{stats}->{min_run} == 0;
@@ -331,7 +288,6 @@ sub _smoke {
   $self->{stats}->{avg_run} = $self->{stats}->{_sum} / $self->{stats}->{totaljobs};
   $self->{stats}->{idle}++ if $result->{idle_kill};
   $self->{stats}->{excess}++ if $result->{excess_kill};
-  $self->{_jobs}--;
   return;
 }
 
